@@ -1,13 +1,16 @@
+import os
 import atexit
 
 from pysyte.bash.shell import run
 
 _alt_screen_started = False
 
+_TERM = "xterm"
+
 
 def _stop_alt_screen():
     if _alt_screen_started:
-        run("tput rmcup")
+        run(f"TERM={_TERM} tput rmcup")
 
 
 def _start_alt_screen():
@@ -21,5 +24,7 @@ def get_alt_screens():
 
 
 def alt_screen():
+    global _TERM
+    _TERM = os.environ.get("TERM", "xterm")
     atexit.register(_stop_alt_screen)
     return _start_alt_screen
