@@ -2,9 +2,8 @@
 
 import itertools
 
-from typing import Any
+from typing import Iterable
 from typing import List
-from typing import Sequence
 from typing import TypeVar
 
 Unique = TypeVar("Unique")  # Generic type
@@ -23,26 +22,21 @@ class Uniques(list):
 
     def predicate(self, _: Unique) -> bool:
         """Subclasses can exclude items which return False"""
-        # pylint: disable=no-self-use
         return True
 
-    def convert(self, item: Any) -> Unique:
+    def convert(self, item: Unique) -> Unique:
         return item
 
-    def append(self, item: Sequence) -> bool:
+    def append(self, item: Unique) -> None:
         if item in self:
-            return False
+            return
         if not self.predicate(item):
-            return False
+            return
         super().append(self.convert(item))
-        return True
 
-    def extend(self, items: Sequence) -> bool:
-        result = False
+    def extend(self, items: Iterable[Unique]) -> None:
         for item in items or []:
-            if self.append(item):
-                result = True
-        return result
+            self.append(item)
 
 
 class UniquelyTrues(Uniques):
@@ -84,7 +78,6 @@ def flatten_(list_of_lists: List[List]) -> List:
 
 def as_list(item):
     """Make item a list from types which can index, have items, or can pop"""
-    # pylint: disable=pointless-statement
     try:
         item.index
         return list(item)
